# -*- coding: utf-8 -*-
from django.contrib.admin import SimpleListFilter
import datetime


class DecadeBornListFilter(SimpleListFilter):
    # Human-readable title which will be displayed in the
    # right admin sidebar just above the filter options.
    title = 'Cotisations'

    # Parameter for the filter that will be used in the URL query.
    parameter_name = 'fee'

    def lookups(self, request, model_admin):
        """
        Returns a list of tuples. The first element in each
        tuple is the coded value for the option that will
        appear in the URL query. The second element is the
        human-readable name for the option that will appear
        in the right sidebar.
        """
        return (
            ('ok', 'À jour de cotisation'),
            ('retard', 'En retard'),
        )

    def queryset(self, request, queryset):
        """
        Returns the filtered queryset based on the value
        provided in the query string and retrievable via
        `self.value()`.
        """
        # Compare the requested value (either '80s' or '90s')
        # to decide how to filter the queryset.
        if self.value() == 'ok':
            return queryset.filter(
                membershipfee__start_date__lte=datetime.date.today,
                membershipfee__end_date__gte=datetime.date.today)
        if self.value() == 'retard':
            return queryset.exclude(
                membershipfee__start_date__lte=datetime.date.today,
                membershipfee__end_date__gte=datetime.date.today)
        #if self.value() == '90s':
            #return queryset.filter(birthday__gte=date(1990, 1, 1),
                                    #birthday__lte=date(1999, 12, 31))
